@@ -40,7 +40,7 @@ static void map_way_color(potlatch_conf_t *potlatch, way_t *way) {
     }
   }
   
-  while(plcol) {  // (way->color == MAP_COLOR_NONE && plcol) 
+  while(plcol) {
     if(osm_way_has_key_or_value(way, plcol->tag)) {
       way->color = (plcol->color << 8) | 0xff;
       if(plcol->stroke) way->draw_flags |= OSM_DRAW_FLAGS_STROKE;
@@ -91,7 +91,7 @@ static void map_statusbar(map_t *map, map_item_t *map_item) {
   }
 
   if(id == ID_ILLEGAL) 
-    str = g_strdup_printf("Unknown item");
+    str = g_strdup_printf(_("Unknown item"));
   else {
     str = g_strdup_printf("%s #%ld", item_str, id);
 
@@ -663,12 +663,9 @@ static void map_node_move(appdata_t *appdata, map_item_t *map_item,
   /* convert mouse position to canvas (world) position */
   canvas_window2world(map->canvas, ex, ey, &node->lpos.x, &node->lpos.y);
 	    
-  /* convert screen position back to utm/ll */
-  utm_t utm = osm->bounds->center;  /* set zone/band */
-  utm.easting  =  node->lpos.x + osm->bounds->center.easting;
-  utm.northing = -node->lpos.y + osm->bounds->center.northing;
-  
-  utm_utm2pos(&utm, &node->pos);
+  /* convert screen position back to ll */
+  lpos2pos(osm->bounds, &node->lpos, &node->pos);
+
   printf("  now at %d %d (%f %f)\n", 
 	 node->lpos.x, node->lpos.y, node->pos.lat, node->pos.lon);
   
@@ -907,6 +904,7 @@ static void map_touchnode_update(appdata_t *appdata, gint x, gint y) {
   }
 }
 
+
 static gboolean map_motion_notify_event(GtkWidget *widget, 
                              GdkEventMotion *event, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -914,13 +912,24 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
   gint x, y;
   GdkModifierType state;
 
+#ifdef USE_HILDON
+  /* reduce update frequency on hildon to keep screen update fluid */
+  static guint32 last_time = 0;
+
+  if(event->time - last_time < 100) return FALSE;
+  last_time = event->time;
+#endif
+
   if(!map->pen_down.is) 
     return FALSE;
 
-  /* handle hints */
+#ifdef USE_GNOMECANVAS
+  /* handle hints, hints are handled by goocanvas directly */
   if(event->is_hint)
     gdk_window_get_pointer(event->window, &x, &y, &state);
-  else {
+  else 
+#endif
+  {
     x = event->x;
     y = event->y;
     state = event->state;
@@ -951,6 +960,7 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
     break;
   }
 
+
   return FALSE;  /* forward to further processing */
 }
 
