@@ -50,10 +50,6 @@ static void osm_bounds_dump(bounds_t *bounds) {
   printf("\nBounds: %f->%f %f->%f\n", 
 	 bounds->ll_min.lat, bounds->ll_max.lat, 
 	 bounds->ll_min.lon, bounds->ll_max.lon);
-
-  char str[32];
-  utm2str(str, sizeof(str), &bounds->center);
-  printf("   -> map center is at %s\n", str);
 }
 
 static bounds_t *osm_parse_osm_bounds(osm_t *osm, 
@@ -106,15 +102,23 @@ static bounds_t *osm_parse_osm_bounds(osm_t *osm,
   pos_t center = { (bounds->ll_max.lat + bounds->ll_min.lat)/2, 
 		   (bounds->ll_max.lon + bounds->ll_min.lon)/2 };
 
-  utm_pos2utm(&center, &bounds->center, NULL);
+  pos2lpos_center(&center, &bounds->center);
 
-  utm_t utm;
-  utm_pos2utm(&bounds->ll_min, &utm, &bounds->center);
-  bounds->min.x = utm.easting - bounds->center.easting;
-  bounds->min.y = utm.northing - bounds->center.northing;
-  utm_pos2utm(&bounds->ll_max, &utm, &bounds->center);
-  bounds->max.x = utm.easting - bounds->center.easting;
-  bounds->max.y = utm.northing - bounds->center.northing;
+  /* the scale is needed to accomodate for "streching" */
+  /* by the mercartor projection */
+  bounds->scale = cos(DEG2RAD(center.lat));
+
+  pos2lpos_center(&bounds->ll_min, &bounds->min);
+  bounds->min.x -= bounds->center.x;
+  bounds->min.y -= bounds->center.y;
+  bounds->min.x *= bounds->scale;
+  bounds->min.y *= bounds->scale;
+
+  pos2lpos_center(&bounds->ll_max, &bounds->max);
+  bounds->max.x -= bounds->center.x;
+  bounds->max.y -= bounds->center.y;
+  bounds->max.x *= bounds->scale;
+  bounds->max.y *= bounds->scale;
 
   return bounds;
 }
@@ -317,11 +321,7 @@ static node_t *osm_parse_osm_node(osm_t *osm,
     }
   }
 
-  /* create utm coordinates */
-  utm_t utm;
-  utm_pos2utm(&node->pos, &utm, &osm->bounds->center);
-  node->lpos.x =   utm.easting - osm->bounds->center.easting;
-  node->lpos.y = -utm.northing + osm->bounds->center.northing;
+  pos2lpos(osm->bounds, &node->pos, &node->lpos);
 
   return node;
 }
@@ -1034,12 +1034,9 @@ node_t *osm_node_new(osm_t *osm, gint x, gint y) {
   node->tag->key = g_strdup("created_by");
   node->tag->value = g_strdup(PACKAGE " v" VERSION);
 
-  /* convert screen position back to utm/ll */
-  utm_t utm = osm->bounds->center;  /* set zone/band */
-  utm.easting  =  node->lpos.x + osm->bounds->center.easting;
-  utm.northing = -node->lpos.y + osm->bounds->center.northing;
-  
-  utm_utm2pos(&utm, &node->pos);
+  /* convert screen position back to ll */
+  lpos2pos(osm->bounds, &node->lpos, &node->pos);
+
   printf("  new at %d %d (%f %f)\n", 
 	 node->lpos.x, node->lpos.y, node->pos.lat, node->pos.lon);
 
