@@ -33,7 +33,8 @@ typedef gulong item_id_t;
 typedef struct bounds_s {
   pos_t ll_min, ll_max;
   lpos_t min, max;
-  utm_t center;
+  lpos_t center;
+  float scale;
 } bounds_t;
 
 typedef struct user_s {
