@@ -24,6 +24,6 @@
 
 gboolean osm_download(GtkWidget *parent, appdata_t *appdata, 
 		      project_t *project);
-void osm_upload(appdata_t *appdata, gpx_t *gpx, project_t *project);
+void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project);
 
 #endif // OSM_API_H
